==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/component/signalprovisionsandrequirements/impl/ProvidedExecutablePropertySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.ExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.ProvisionSet;
import io.ciera.tool.sql.ooaofooa.component.impl.ExecutablePropertySetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.ProvisionSetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedExecutableProperty;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedOperationSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedSignalSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.ProvidedOperationSetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.ProvidedSignalSetImpl;
import io.ciera.tool.sql.ooaofooa.value.MessageValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.MessageValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class ProvidedExecutablePropertySetImpl extends InstanceSet<ProvidedExecutablePropertySet,ProvidedExecutableProperty> implements ProvidedExecutablePropertySet {

    // attributes
    @Override
    public void setExecutableProperty_Id( UniqueId ref_ExecutableProperty_Id ) throws XtumlException {
        for ( ProvidedExecutableProperty providedexecutableproperty : this ) providedexecutableproperty.setExecutableProperty_Id( ref_ExecutableProperty_Id );
    }
    @Override
    public void setId( UniqueId m_Id ) throws XtumlException {
        for ( ProvidedExecutableProperty providedexecutableproperty : this ) providedexecutableproperty.setId( m_Id );
    }
    @Override
    public void setProvision_Id( UniqueId ref_Provision_Id ) throws XtumlException {
        for ( ProvidedExecutableProperty providedexecutableproperty : this ) providedexecutableproperty.setProvision_Id( ref_Provision_Id );
    }


    // selections
    @Override
    public ExecutablePropertySet R4501_implements_ExecutableProperty() throws XtumlException {
        ExecutablePropertySet executablepropertyset = new ExecutablePropertySetImpl();
        for ( ProvidedExecutableProperty providedexecutableproperty : this ) executablepropertyset.add( providedexecutableproperty.R4501_implements_ExecutableProperty() );
        return executablepropertyset;
    }
    @Override
    public ProvisionSet R4501_is_implemented_by_Provision() throws XtumlException {
        ProvisionSet provisionset = new ProvisionSetImpl();
        for ( ProvidedExecutableProperty providedexecutableproperty : this ) provisionset.add( providedexecutableproperty.R4501_is_implemented_by_Provision() );
        return provisionset;
    }
    @Override
    public ProvidedOperationSet R4503_is_a_ProvidedOperation() throws XtumlException {
        ProvidedOperationSet providedoperationset = new ProvidedOperationSetImpl();
        for ( ProvidedExecutableProperty providedexecutableproperty : this ) providedoperationset.add( providedexecutableproperty.R4503_is_a_ProvidedOperation() );
        return providedoperationset;
    }
    @Override
    public ProvidedSignalSet R4503_is_a_ProvidedSignal() throws XtumlException {
        ProvidedSignalSet providedsignalset = new ProvidedSignalSetImpl();
        for ( ProvidedExecutableProperty providedexecutableproperty : this ) providedsignalset.add( providedexecutableproperty.R4503_is_a_ProvidedSignal() );
        return providedsignalset;
    }
    @Override
    public MessageValueSet R841_MessageValue() throws XtumlException {
        MessageValueSet messagevalueset = new MessageValueSetImpl();
        for ( ProvidedExecutableProperty providedexecutableproperty : this ) messagevalueset.addAll( providedexecutableproperty.R841_MessageValue() );
        return messagevalueset;
    }


    @Override
    public ProvidedExecutableProperty nullElement() {
        return ProvidedExecutablePropertyImpl.EMPTY_PROVIDEDEXECUTABLEPROPERTY;
    }

    @Override
    public ProvidedExecutablePropertySet emptySet() {
      return new ProvidedExecutablePropertySetImpl();
    }

    @Override
    public ProvidedExecutablePropertySet value() {
        return this;
    }

    @Override
    public List<ProvidedExecutableProperty> elements() {
        return Arrays.asList(toArray(new ProvidedExecutableProperty[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/component/signalprovisionsandrequirements/impl/ProvidedExecutablePropertySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.ExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.ProvisionSet;
import io.ciera.tool.sql.ooaofooa.component.impl.ExecutablePropertySetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.ProvisionSetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedExecutableProperty;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedOperationSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedSignalSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.ProvidedOperationSetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.ProvidedSignalSetImpl;
import io.ciera.tool.sql.ooaofooa.value.MessageValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.MessageValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ProvidedExecutablePropertySetImpl extends InstanceSet<ProvidedExecutablePropertySet,ProvidedExecutableProperty> implements ProvidedExecutablePropertySet {

    public ProvidedExecutablePropertySetImpl() {
    }

    public ProvidedExecutablePropertySetImpl(Comparator<? super ProvidedExecutableProperty> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setId( UniqueId m_Id ) throws XtumlException {
        for ( ProvidedExecutableProperty providedexecutableproperty : this ) providedexecutableproperty.setId( m_Id );
    }
    @Override
    public void setProvision_Id( UniqueId ref_Provision_Id ) throws XtumlException {
        for ( ProvidedExecutableProperty providedexecutableproperty : this ) providedexecutableproperty.setProvision_Id( ref_Provision_Id );
    }
    @Override
    public void setExecutableProperty_Id( UniqueId ref_ExecutableProperty_Id ) throws XtumlException {
        for ( ProvidedExecutableProperty providedexecutableproperty : this ) providedexecutableproperty.setExecutableProperty_Id( ref_ExecutableProperty_Id );
    }


    // selections
    @Override
    public ExecutablePropertySet R4501_implements_ExecutableProperty() throws XtumlException {
        ExecutablePropertySet executablepropertyset = new ExecutablePropertySetImpl();
        for ( ProvidedExecutableProperty providedexecutableproperty : this ) executablepropertyset.add( providedexecutableproperty.R4501_implements_ExecutableProperty() );
        return executablepropertyset;
    }
    @Override
    public ProvisionSet R4501_is_implemented_by_Provision() throws XtumlException {
        ProvisionSet provisionset = new ProvisionSetImpl();
        for ( ProvidedExecutableProperty providedexecutableproperty : this ) provisionset.add( providedexecutableproperty.R4501_is_implemented_by_Provision() );
        return provisionset;
    }
    @Override
    public ProvidedOperationSet R4503_is_a_ProvidedOperation() throws XtumlException {
        ProvidedOperationSet providedoperationset = new ProvidedOperationSetImpl();
        for ( ProvidedExecutableProperty providedexecutableproperty : this ) providedoperationset.add( providedexecutableproperty.R4503_is_a_ProvidedOperation() );
        return providedoperationset;
    }
    @Override
    public ProvidedSignalSet R4503_is_a_ProvidedSignal() throws XtumlException {
        ProvidedSignalSet providedsignalset = new ProvidedSignalSetImpl();
        for ( ProvidedExecutableProperty providedexecutableproperty : this ) providedsignalset.add( providedexecutableproperty.R4503_is_a_ProvidedSignal() );
        return providedsignalset;
    }
    @Override
    public MessageValueSet R841_MessageValue() throws XtumlException {
        MessageValueSet messagevalueset = new MessageValueSetImpl();
        for ( ProvidedExecutableProperty providedexecutableproperty : this ) messagevalueset.addAll( providedexecutableproperty.R841_MessageValue() );
        return messagevalueset;
    }


    @Override
    public ProvidedExecutableProperty nullElement() {
        return ProvidedExecutablePropertyImpl.EMPTY_PROVIDEDEXECUTABLEPROPERTY;
    }

    @Override
    public ProvidedExecutablePropertySet emptySet() {
      return new ProvidedExecutablePropertySetImpl();
    }

    @Override
    public ProvidedExecutablePropertySet emptySet(Comparator<? super ProvidedExecutableProperty> comp) {
      return new ProvidedExecutablePropertySetImpl(comp);
    }

    @Override
    public ProvidedExecutablePropertySet value() {
        return this;
    }

    @Override
    public List<ProvidedExecutableProperty> elements() {
        return Arrays.asList(toArray(new ProvidedExecutableProperty[0]));
    }

}
